@@ -21,11 +21,14 @@ from convex_api.exceptions import (
     ConvexAPIError,
     ConvexRequestError
 )
+from convex_api.registry import Registry
 from convex_api.utils import (
     is_address,
     to_address
 )
 
+# min amount to do a topup account
+TOPUP_ACCOUNT_MIN_BALANCE = 10000000
 
 logger = logging.getLogger(__name__)
 
@@ -42,6 +45,7 @@ class ConvexAPI:
         if language not in ConvexAPI.LANGUAGE_ALLOWED:
             raise ValueError(f'Invalid language: {language}')
         self._language = language
+        self._registry = Registry(self)
 
     def create_account(self, account=None, sequence_retry_count=20):
         """
@@ -50,16 +54,17 @@ class ConvexAPI:
 
         :param `Account` account: :class:`.Account` object that you whish to use as the signing account.
             The :class:`.Account` object contains the public/private keys to access and submit commands
-            on the convex network. The address property will be changed by this method.
+            on the convex network.
 
             If no object given, then this method will automatically create a new :class:`.Account` object.
         :type account: Account, optional
 
+
         :param sequence_retry_count: Number of retries to create the account. If too many clients are trying to
             create accounts on the same node, then we will get sequence errors.
         :type sequence_retry_count: int, optional
 
-        :returns: A new :class:`.Account` object, or the current supplied :class:`.Account` object with a new `address` property set
+        :returns: A new :class:`.Account` object, or copy of the :class:`.Account` object with a new `address` property value set
 
 
         .. code-block:: python
@@ -72,17 +77,19 @@ class ConvexAPI:
             >>> 42
 
             >>> #create a new account address, but use the same keys as `account`
-            >>> new_account_address = convex_api.create_account(account)
+            >>> new_account_address = convex_api.create_account(account=account)
             >>> print(new_account.address)
             >>> 43
 
 
         """
 
+        if account and not isinstance(account, Account):
+            raise TypeError(f'account value {account} must be a type convex_api.Account')
+
         # if account, then copy it
         if account:
-            new_account = account.copy()
-            new_account.address = None
+            new_account = Account.import_from_account(account)
         else:
             # create a new account with new keys
             new_account = Account.create()
@@ -114,8 +121,132 @@ class ConvexAPI:
                 raise ConvexRequestError('create_account', response.status_code, response.text)
         logger.debug(f'create_account result {result}')
         new_account.address = to_address(result['address'])
+
         return new_account
 
+    def load_account(self, name, account):
+        """
+
+        Load an account using the account name. If successfull return the :class:`.Account` object with the address set.
+
+        This is a Query operation, so no convex tokens are used in loading the account.
+
+        :param str name: name of the account to load
+        :param Account account: :class:`.Account` object to import
+
+        :results: :class:`.Account` object with the address and name set, if not found then return None
+
+
+        .. code-block:: python
+
+            >>> # Create a new account with new public/priavte keys and address
+            >>> import_account = Account.import_from_file('my_account.pem', 'secret')
+            >>> account = convex.load_account('my_account, import_account)
+            >>> print(account.name)
+            my_account
+            >>> print(account.address)
+            930
+
+        """
+        address = self.resolve_account_name(name)
+        if address:
+            new_account = Account.import_from_account(account, address=address, name=name)
+            return new_account
+
+    def setup_account(self, name, import_account, register_account=None):
+        """
+
+        Convenience method to create or load an account based on the account name.
+        If the account name cannot be found then account will be created and account name registered,
+        if the name is found, then account and it's address with that name will be loaded.
+
+        :param str name: name of the account to create or load
+        :param Account account: :class:`.Account` object to import
+        :param Account register_account: Optional :class:`.Account` object to use for registration of the account
+
+        :results: :class:`.Account` object with the address and name set, if not found then return None
+
+        **Note** If you do not provide a register_account, then this method calls the
+        :meth:`.topup_account` method to get enougth funds to register an account name.
+
+
+        .. code-block:: python
+
+            >>> import_account = Account.import_from_file('my_account.pem', 'secret')
+            >>> # create or load the account named 'my_account'
+            >>> account = convex.setup_account('my_account', import_account)
+            >>> print(account.name)
+            my_account
+
+        """
+
+        # check to see if we can resolve the account name
+        if self.resolve_account_name(name):
+            # if so just load the account
+            account = self.load_account(name, import_account)
+        else:
+            # new name , so first create the account
+            account = self.create_account(account=import_account)
+            if not register_account:
+                # make sure we have enougth funds to do the registration
+                self.topup_account(account)
+                register_account = account
+            account = self.register_account_name(name, account, register_account)
+        return account
+
+    def register_account_name(self, name, address_account, account=None):
+        """
+
+        Register or update an account address with an account name.
+
+        This call will submit to the CNS (Convex Name Service), a name in the format
+        "`account.<your_name>`". You need to have some convex balance in your account, and
+        a valid account address.
+
+        :param str name: name of the account to register.
+        :param number|Account account_address: Account or address to register.
+        :param Account account: :class:`.Account` object to register the account name.
+
+        .. code-block:: python
+
+            >>> # load the register account
+            >>> register_account = convex.load_account('register_account', import_account)
+            >>> account = convex.create_account(import_account)
+            >>> print(account.address)
+            1024
+            >>> account = convex.register_account('my_new_account', account.address, register_account)
+            >>> print(account.address)
+            1024
+
+            # or you can call with only one account, this will use the address of that account
+            >>> print(register_account.address)
+            404
+            >>> account = convex.register_account('my_new_account', register_account)
+            >>> print(account.address)
+            404
+
+        """
+
+        # is the address_account field only an address?
+        if is_address(address_account):
+            address = to_address(address_account)
+        else:
+            # if account then use the account address, and also see if we can use it for the
+            # registration
+            address = address_account.address
+            if account is None:
+                account = address_account
+
+        # we must have a valid account to do the registration
+        if not account:
+            raise ValueError('you need to provide a registration account to register an account name')
+
+        if not address:
+            raise ValueError('You need to provide a valid address to register an account name')
+
+        self._registry.register(f'account.{name}', address, account)
+        return Account.import_from_account(account, address=address, name=name)
+
     def send(self, transaction, account, language=None, sequence_retry_count=20):
         """
         Send transaction code to the block chain node.
@@ -257,7 +388,7 @@ class ConvexAPI:
             raise ValueError(f'request_funds: returned account is not correct {result["address"]}')
         return result['amount']
 
-    def topup_account(self, account, min_balance=1000000, retry_count=8):
+    def topup_account(self, account, min_balance=TOPUP_ACCOUNT_MIN_BALANCE, retry_count=8):
         """
 
         Topup an account from the block chain faucet, so that the balance of the account is above or equal to
@@ -286,7 +417,7 @@ class ConvexAPI:
 
         """
 
-        request_amount = min(10000000, min_balance)
+        request_amount = min(TOPUP_ACCOUNT_MIN_BALANCE, min_balance)
         retry_count = min(5, retry_count)
         transfer_amount = 0
         while min_balance > self.get_balance(account) and retry_count > 0:
@@ -454,9 +585,6 @@ class ConvexAPI:
             'isLibrary': False, 'isActor': False, 'allowance': 0,
             'sequence': 0, 'type': 'user'}
 
-
-
-
         """
         if is_address(address_account):
             address = to_address(address_account)
@@ -474,6 +602,32 @@ class ConvexAPI:
         logger.debug(f'get_account_info repsonse {result}')
         return result
 
+    def resolve_account_name(self, name):
+        """
+        Resolves an account name to an address.
+        :param string name Name of the account to resolve.
+
+        .. code-block:: python
+
+            >>> convex.resolve_account_name('my_account')
+            405
+
+        """
+        return self._registry.resolve_address(f'account.{name}')
+
+    def resolve_name(self, name):
+        """
+        Resolves any Convex Name Services to an address.
+        :param string name Name of the the CNS Service.
+
+        .. code-block:: python
+
+            >>> convex.resolve_account_name('convex.nft-tokens')
+            25
+
+        """
+        return self._registry.resolve_address(name)
+
     def _transaction_prepare(self, address, transaction, language=None, sequence_number=None):
         """
 
@@ -554,3 +708,7 @@ class ConvexAPI:
 
         """
         return self._language
+
+    @property
+    def registry(self):
+        return self._registry
